using System.ComponentModel.DataAnnotations;
using Microsoft.AspNetCore.Mvc;
using Todo.Core.Interfaces.Persistence;

namespace Todo.Api.Controllers;

[ApiController]
[Route("/api/todos")]
public class TodosController : ControllerBase
{
    private readonly ITodoRepository _todoRepository;

    public TodosController(ITodoRepository todoRepository)
    {
        _todoRepository = todoRepository;
    }

    [HttpPost]
    public async Task<ActionResult<Core.Entities.Todo>> CreateTodo([FromBody] CreateTodoRequest request) =>
        Ok(await _todoRepository.CreateTodoAsync(request.Title));

    [HttpGet]
    public async Task<ActionResult<IEnumerable<Core.Entities.Todo>>> GetTodos() =>
        Ok(await _todoRepository.GetTodosAsync());

    [HttpGet]
    public async Task<ActionResult<IEnumerable<Core.Entities.Todo>>> GetNotDoneTodos() =>
        Ok(await _todoRepository.GetNotDoneTodos());

    public record CreateTodoRequest
    {
        [Required] public string Title { get; init; }
    }
}