using System.Text.Json;
using Microsoft.AspNetCore.SignalR;
using Todo.Api.Hubs.Models;
using Todo.Core.Interfaces.Persistence;

namespace Todo.Api.Hubs
{
    public class TodoHub : Hub
    {
        private readonly ITodoRepository _todoRepository;

        public TodoHub(ITodoRepository todoRepository)
        {
            _todoRepository = todoRepository;
        }

        public async Task CreateTodo(string todoTitle)
        {
            var _ = await _todoRepository.CreateTodoAsync(todoTitle);

            var todos = await _todoRepository.GetNotDoneTodos();
            var serializedTodos =
                JsonSerializer.Serialize(todos
                    .Select(t => new TodoResponse { Id = t.Id, Title = t.Title })
                    .ToList());

            await Clients.Caller.SendAsync("getInboxTodos", serializedTodos);
        }

        public async Task UpdateTodo(string todoId, bool todoStatus)
        {
            await _todoRepository.UpdateTodoStatus(todoId, todoStatus);

            var todos = await _todoRepository.GetNotDoneTodos();
            var serializedTodos =
                JsonSerializer.Serialize(todos
                    .Select(t => new TodoResponse { Id = t.Id, Title = t.Title, Status = t.Status })
                    .ToList());

            await Clients.Caller.SendAsync("getInboxTodos", serializedTodos);
        }

        public async Task GetTodos()
        {
            var todos = await _todoRepository.GetTodosAsync();
            var serializedTodos = JsonSerializer.Serialize(todos
                .Select(t => new TodoResponse { Id = t.Id, Title = t.Title, Status = t.Status })
                .ToList());

            await Clients.Caller.SendAsync("todos", serializedTodos);
        }


        public async Task GetInboxTodos()
        {
            var todos = await _todoRepository.GetNotDoneTodos();
            var serializedTodos = JsonSerializer.Serialize(todos
                .Select(t => new TodoResponse { Id = t.Id, Title = t.Title, Status = t.Status })
                .ToList());

            await Clients.Caller.SendAsync("getInboxTodos", serializedTodos);
        }
    }
}