global using System;
global using System.Threading.Tasks;
global using System.Linq;
global using System.Collections.Generic;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Diagnostics.HealthChecks;
using Todo.Core.Interfaces.Persistence;
using Todo.Persistence.Mongo;
using Todo.Persistence.Mongo.Repositories;

namespace Todo.Persistence
{
    public static class DependencyInjection
    {
        public static IServiceCollection AddPersistence(this IServiceCollection services, IConfiguration configuration,
            out MongoDbOptions mongoDbOptions)
        {
            var exportableMongoDbOptions = new MongoDbOptions();
            var options = configuration.GetRequiredSection("MONGODB");
            options.Bind(exportableMongoDbOptions);
            mongoDbOptions = exportableMongoDbOptions;

            services
                .AddOptions<MongoDbOptions>()
                .Bind(options)
                .ValidateDataAnnotations();

            return services
                .AddSingleton<MongoDbConnectionHandler>()
                .AddScoped<IUserRepository, UserRepository>()
                .AddScoped<ITodoRepository, TodoRepository>();
        }
    }
}