using Microsoft.AspNetCore.Builder;
using Microsoft.Extensions.DependencyInjection;
using MongoDB.Driver;
using Todo.Persistence.Mongo.Repositories.Dtos;

namespace Todo.Persistence.Mongo
{
    public static class Migrations
    {
        public static IApplicationBuilder MigrateMongoDb(this IApplicationBuilder app)
        {
            Task.Run(async () =>
            {
                var connectionHandler = app.ApplicationServices.GetRequiredService<MongoDbConnectionHandler>();
                var database = connectionHandler.CreateDatabaseConnection();

                await CreateIndexes(database);
            }).Wait(10000);

            return app;
        }

        private static async Task CreateIndexes(IMongoDatabase mongoDatabase)
        {
            Console.WriteLine("Running: CreateIndexes");
            var collection = mongoDatabase.GetCollection<MongoUser>("users");
            var indexKeysDefinition = Builders<MongoUser>.IndexKeys.Ascending(user => user.Email);
            var indexModel =
                new CreateIndexModel<MongoUser>(indexKeysDefinition, new CreateIndexOptions() { Unique = true });

            await collection.Indexes.CreateOneAsync(indexModel);
            Console.WriteLine("Finished: CreateIndexes");
        }
    }
}